import lodash from 'lodash'
import { interact, replaceApiParams } from '../../utils'
import apis from '../../config/api'

export default {
  namespaced: true,
  state: {
    banners: {},
    detail: {}
  },
  mutations: {
    updateList (state, payload) {
      state.banners = payload
    },
    updateDetail (state, payload) {
      state.detail = payload
    }
  },
  actions: {
    setDetailNull ({ commit }) {
      commit('updateDetail', {})
    },
    getBanners ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        const api = lodash.get(apis, 'banner.list')
        interact(api, payload).then((data) => {
          commit('updateList', data)
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    },
    getDetail ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        const api = replaceApiParams(lodash.get(apis, 'banner.detail'), payload)
        interact(api).then((data) => {
          commit('updateDetail', data)
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    },
    addBanner (_, payload) {
      return new Promise((resolve, reject) => {
        const api = lodash.get(apis, 'banner.add')
        interact(api, payload).then((data) => {
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    },
    editBanner (_, payload) {
      return new Promise((resolve, reject) => {
        const api = lodash.get(apis, 'banner.update')
        interact(api, payload).then((data) => {
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    },
    deleteBanner (_, payload) {
      return new Promise((resolve, reject) => {
        const api = lodash.get(apis, 'banner.delete')
        interact(api, payload).then(() => {
          resolve()
        }).catch(() => {
          reject()
        })
      })
    }
  }
}