import lodash from 'lodash'
import { interact, replaceApiParams } from '../../utils'
import apis from '../../config/api'

export default {
  namespaced: true,
  state: {
    comments: {},
    detail: {}
  },
  mutations: {
    updateList (state, payload) {
      state.comments = payload
    },
    updateDetail (state, payload) {
      state.detail = payload
    }
  },
  actions: {
    setDetailNull ({ commit }) {
      commit('updateDetail', {})
    },
    getComments ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        const api = lodash.get(apis, 'comment.list')
        interact(api, payload).then((data) => {
          commit('updateList', data)
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    },
    delComment (_, payload) {
      return new Promise((resolve, reject) => {
        const api = replaceApiParams(lodash.get(apis, 'comment.delete'), payload)
        interact(api).then((data) => {
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    },
    getCommentInfo ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        const api = replaceApiParams(lodash.get(apis, 'comment.detail'), payload)
        interact(api).then((data) => {
          commit('updateDetail', data)
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    },
    addComment (_, payload) {
      return new Promise((resolve, reject) => {
        const api = lodash.get(apis, 'comment.add')
        interact(api, payload).then((data) => {
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    }
  }
}