import lodash from 'lodash'
import { interact, replaceApiParams } from '../../utils'
import apis from '../../config/api'

export default {
  namespaced: true,
  state: {
    dynamics: {},
    detail: {}
  },
  mutations: {
    updateList (state, payload) {
      state.dynamics = payload
    },
    updateDetail (state, payload) {
      state.detail = payload
    }
  },
  actions: {
    setDetailNull ({ commit }) {
      commit('updateDetail', {})
    },
    getDynamics ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        const api = lodash.get(apis, 'dynamic.list')
        interact(api, payload).then((data) => {
          commit('updateList', data)
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    },
    getDetail ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        const api = replaceApiParams(lodash.get(apis, 'dynamic.detail'), payload)
        interact(api).then((data) => {
          commit('updateDetail', data)
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    },
    addDynamics (_, payload) {
      return new Promise((resolve, reject) => {
        const api = lodash.get(apis, 'dynamic.add')
        interact(api, payload.detail).then((data) => {
          resolve(data)
        }).catch(({ message }) => {
          reject(message)
        })
      })
    },
    editDynamics (_, payload) {
      return new Promise((resolve, reject) => {
        const api = lodash.get(apis, 'dynamic.edit')
        interact(api, payload.detail).then((data) => {
          resolve(data)
        }).catch(({ message }) => {
          reject(message)
        })
      })
    },
    deleteDynamics (_, payload) {
      return new Promise((resolve, reject) => {
        const api = lodash.get(apis, 'dynamic.delete')
        interact(api, payload).then(() => {
          resolve()
        }).catch(() => {
          reject()
        })
      })
    },
    publicDynamic (_, payload) {
      return new Promise((resolve, reject) => {
        const api = replaceApiParams(lodash.get(apis, 'dynamic.public'), payload)
        interact(api).then((data) => {
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    },
    cancelDynamic (_, payload) {
      return new Promise((resolve, reject) => {
        const api = replaceApiParams(lodash.get(apis, 'dynamic.cancel'), payload)
        interact(api).then((data) => {
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    }
  }
}